from mindstorms import MSHub, Motor, MotorPair, ColorSensor, DistanceSensor, App
from mindstorms.control import wait_for_seconds, wait_until, Timer
from mindstorms.operator import greater_than, greater_than_or_equal_to, less_than, less_than_or_equal_to, equal_to, not_equal_to
import math


# Variables for the various numerical values
distance = 100          # lap distance in cm
turn_rotations = 2.27   # number of wheels rotations to make a U-turn with one drive wheel (other drive wheel stopped)
laps = 3                # number of laps (out and back) to do

# Variables for the objects
hub = MSHub()
lift = Motor('C')
blade = Motor('D')
drive_motors = MotorPair('A', 'B')
left_motor = Motor('A')
right_motor = Motor('B')


# The main program
def main():
    # Make sure the steering lift is all the way up
    lift.run_for_seconds(1, -20)
    lift.set_default_speed(100)

    # Start the mower blade
    blade.start(100)
    hub.light_matrix.show_image('NO')    # Makes an X shape. No way to do animations?

    # Do the laps
    drive_motors.set_default_speed(50)
    for lap in range(laps):
        drive_motors.move(distance, 'cm')
        turn_right()
        drive_motors.move(distance, 'cm')
        turn_left()

    # Stop mower blade
    blade.stop()
    hub.light_matrix.show_image('TARGET')


# Deploy (lower) the turning lift
def lift_deploy():
    lift.run_for_degrees(90)


# Retract (raise) the turning lift
def lift_retract():
    lift.run_for_degrees(-90)


# Make a U-turn to the right using the steering lift
def turn_right():
    lift_deploy()
    left_motor.run_for_rotations(-turn_rotations)
    lift_retract()


# Make a U-turn to the left using the steering lift
def turn_left():
    lift_deploy()
    right_motor.run_for_rotations(turn_rotations)
    lift_retract()


# Run the main program once everything is defined
main()


